#!/usr/bin/env python

import pygtk
pygtk.require('2.0')
import gtk
import os
import sys
import signal
import time

started = None
statusIcon = None

def main():
    input = sys.stdin.readline()
    message = ""
    if len(input) > 1:
        for mountpoint in input[0:len(input)-1].split(":"):
            message += "    " + mountpoint + "\n"

    if len(message) > 1:
        global statusIcon
        if "LTSPFS_NOTIFICATION_ICON" in os.environ:
            iconTheme = gtk.icon_theme_get_default()
            iconName = os.environ["LTSPFS_NOTIFICATION_ICON"]
            if iconTheme.has_icon(iconName):
                statusIcon = gtk.status_icon_new_from_icon_name(iconName)
            elif os.path.isfile(iconName):
                statusIcon = gtk.status_icon_new_from_file(iconName)
        if statusIcon is None:
            statusIcon = gtk.status_icon_new_from_icon_name("gnome-dev-removable-usb")
        if statusIcon is not None:
            statusIcon.set_tooltip("The following devices are mounted:\n" + message[0:len(message)-1])

            menu = gtk.Menu()
            menuItem = gtk.ImageMenuItem(gtk.STOCK_QUIT)
            menuItem.connect('activate', gtk.main_quit)
            menu.append(menuItem)

            statusIcon.connect('popup-menu', popup_menu_cb, menu)
            statusIcon.set_visible(True)

        gtk.main()

def popup_menu_cb(widget, button, time, data = None):
    if button == 3:
        if data:
            global statusIcon
            data.show_all()
            data.popup(None, None, gtk.status_icon_position_menu,
               button, time, statusIcon)

# The reason for the delayed HUP handling is that if an umount and a mount
# event occured very close to each other (within a few milliseconds),
# sometimes the mount event comes through first and the umount follows
# (probably because of the ssh command execution latency).
# This results in a notification that immediately disappears.
# However since we know that there's at least a 5s delay between a mount
# and an umount, we can use this to filter out events that come in wrong order.
def sig_handler(signum, frame):
    global started
    # Exit instantly for TERM signals since they come from mount/umount events
    # where there're still remaining active mounts, thus there'll be a new
    # instance of this app.
    if signum != signal.SIGHUP or (started is not None and time.time() - started >= 2.0):
        gtk.main_quit()

if __name__ == "__main__":
    started = time.time()
    # Note: PyGTK has some problem (bug) with USR2 signals.
    # When I used USR2 signals, sometimes the signal handler was not called
    # and the execution stopped as if an exception was thrawn or as if there
    # was no signal handler defined at all. :-o
    # USR1 on the other hand worked just fine.
    # To be on the safe side, I opted for the very basic HUP and TERM signals.
    # They seem to work without any problems.
    signal.signal(signal.SIGHUP, sig_handler)
    signal.signal(signal.SIGTERM, sig_handler)
    # We provide an INT handler too ... just to have a nice exit from INTs.
    signal.signal(signal.SIGINT, sig_handler)
    main()

