#!/bin/sh

boolean_is_true() {
  case $1 in
    # match all cases of true|y|yes|1
    [Tt][Rr][Uu][Ee]|[Yy]|[Yy][Ee][Ss]|1) return 0 ;;
    *) return 1 ;;
  esac
}

LTSPFS_NOTIFICATION_SCRIPT='/etc/ltspfs/ltspfs-mount-notifier-icon.py'
LTSPFS_NOTIFICATION_ICON=gnome-dev-removable-usb
LTSPFS_NOTIFY=True

SYSTEMRC=/etc/default/ltspfs-mount-notifier
[ -f "${SYSTEMRC}"  ] && . "${SYSTEMRC}"

USERRC=.ltspfsrc
[ -n "${HOME}" -a -d "${HOME}" -a -f "${HOME}/${USERRC}" ] && . "${HOME}/${USERRC}"

if boolean_is_true "${LTSPFS_NOTIFY}" && [ -f "${LTSPFS_NOTIFICATION_SCRIPT}" -a -x "${LTSPFS_NOTIFICATION_SCRIPT}" ]; then
  input=$(cat)
  UID=$(id -u)
  REGEX="python +${LTSPFS_NOTIFICATION_SCRIPT}"
  if [ -n "${input}" ]; then
    # Destroy all instances of the icon displaying app. that belong to the
    # current user.
    pkill -TERM -u "${UID}" -f "${REGEX}"
    # In the following command nohup is required so the SSH session on the
    # client (that launched this script) won't stay hanging around.
    # The "tricky" redirection stuff is necessary because of nohup and the
    # requirement to pipe stuff into the usb-notifier-icon.py process.
    # (Normal piping does not work with nohup'ed processes.)
    # First we start the usb-notifier-icon.py subprocess and open the
    # filedescriptor #3. Then we print the message to this FD#3 and finally 
    # we swap FD#3 and stdin.
    export LTSPFS_NOTIFICATION_ICON
    nohup /bin/bash -c "echo '$input' | ${LTSPFS_NOTIFICATION_SCRIPT} $*" > /dev/null 2>&1 &
    # The following wait (sleep) is here so the above app (usb-notifier-icon.py)
    # has enough time to open the display and use it. After this 1s delay the
    # parent SSH connection will exit and the X forwarding is closed. Thus if
    # the usb-notifier-icon.py process tried to do some X stuff later on, it'd
    # run into an error. But it won't so we're all happy. :-)
    sleep 1
  else
    pkill -HUP -u "${UID}" -f "${REGEX}"
  fi
fi

